@@ -1,4 +1,4 @@
-# $Id: install.py 1034 2014-09-16 04:29:54Z mwall $
+# $Id: install.py 1147 2014-11-28 14:14:45Z mwall $
 # installer for the forecast extension
 # Copyright 2014 Matthew Wall
 
@@ -10,33 +10,38 @@ def loader():
 class ForecastInstaller(ExtensionInstaller):
     def __init__(self):
         super(ForecastInstaller, self).__init__(
-            version="2.4.2",
+            version="3.0",
             name='forecast',
             description='Generate and display weather and tide forecasts.',
             author="Matthew Wall",
             author_email="mwall@users.sourceforge.net",
-            process_services=['user.forecast.ZambrettiForecast',
-                              'user.forecast.WUForecast'],
+            archive_services=['user.forecast.ZambrettiForecast',
+                              'user.forecast.WUForecast',
+                              'user.forecast.NWSForecast',
+                              'user.forecast.XTideForecast'],
             config={
                 'Forecast': {
-                    'database': 'forecast_sqlite',
+                    'data_binding': 'forecast_binding',
                     'XTide': {
-                        'location': 'Boston'},
+                        'location': 'INSERT_LOCATION_HERE (e.g., Boston)'},
                     'Zambretti': {
                         'hemisphere': 'NORTH'},
                     'NWS': {
-                        'lid': 'MAZ014',
-                        'foid': 'BOX'},
+                        'lid': 'INSERT_LOCATION_ID_HERE (e.g., MAZ014)',
+                        'foid': 'INSERT_FORECAST_OFFICE_ID_HERE (e.g., BOX)'},
                     'WU': {
                         'api_key': 'INSERT_WU_API_KEY_HERE'}},
+                'DataBindings': {
+                    'forecast_binding': {
+                        'database': 'forecast_sqlite'}},
                 'Databases': {
                     'forecast_sqlite': {
-                        'database': 'forecast.sdb',
+                        'database_name': 'forecast.sdb',
                         'driver': 'weedb.sqlite'}},
                 'StdReport': {
                     'forecast': {
-                        'skin':'forecast',
-                        'HTML_ROOT':'forecast',
+                        'skin': 'forecast',
+                        'HTML_ROOT': 'forecast',
                         'Extras': {
                             'forecast_table':'INST_SKIN_ROOT/forecast/forecast_table.inc'}}}},
             files=[('bin/user',
